<p align="center">
<img src="assets/icon.png" width="200"  alt="">
</p>

<div align="center">
<h1>shuangchentools</h1>
</div>
<p align="center">
<img alt="" src="https://img.shields.io/badge/release-v0.0.5-brightgreen" style="display: inline-block;" />
<img alt="" src="https://img.shields.io/badge/project-open-brightgreen" style="display: inline-block;" />
</p>



封装了一些常用的工具

1. doc_segment：文档分割，包括根据标题规则
2. spider：封装常用爬虫工具，包括selenium自动获取cookies、隐藏特征
3. utils：各类工具函数，包括：
 - 阿拉伯数字转中文, 阿拉伯数字与罗马数字转换
 - 常用装饰器
 - 文件以及文件夹常用操作
 - 异步执行外部程序/命令

#### 安装

```bash
git clone git@github.com:wangtao2001/shuangchentools.git
cd shuangchentools
pip install -e .
```

或

```bash
pip install shuangchentools
```
